"""
PdfInfoExtractor

"""

from utilities import ImagesExtractor, ClassifyFiles, extract_info

__version__ = "0.1.11"
__author__ = 'Steve Richards, Mehak Singal, Nidhish Kumar'
# __credits__ = 'Argonne National Laboratory'